@@ -1,5 +1,5 @@
 # -*- mode: python; coding: utf-8 -*-
-# Copyright © 2019 Göran Weinholt
+# Copyright © 2019, 2020 Göran Weinholt
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
 # This program is free software: you can redistribute it and/or modify
@@ -84,7 +84,12 @@ class LokoPrinter(object):
 
 class LokoFixnumPrinter(LokoPrinter):
     def to_string(self):
-        return "%d" % (self.val >> 3)
+        return "%d" % (self.val >> shift_fixnum)
+
+
+class LokoCharPrinter(LokoPrinter):
+    def to_string(self):
+        return "#\\%c" % (self.val >> shift_char)
 
 
 class LokoPairPrinter(LokoPrinter):
@@ -117,7 +122,7 @@ class LokoBytevectorPrinter(LokoPrinter):
             yield str(i), value
 
     def to_string(self):
-        return "vu8"
+        return "vu8@0x%x" % ((self.val & ~7) + 16)
 
     def display_hint(self):
         return 'array'
@@ -266,7 +271,7 @@ class LokoSingularPrinter(LokoPrinter):
 
 
 def loko_lookup_function(val):
-    if str(val.type) == 'int64_t':
+    if str(val.type) in ('int64_t', 'int', 'long'):
         tag3 = int(val) & 0b111
         if tag3 == tag_fixnum:
             return LokoFixnumPrinter(val)
@@ -322,6 +327,8 @@ def loko_lookup_function(val):
                 return LokoSingularPrinter('#f')
             if value == 1:
                 return LokoSingularPrinter('#t')
+        if tag8 == tag_char:
+            return LokoCharPrinter(val)
 
         return LokoPrinter(val)
 
